% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gg_variable.R
\name{gg_variable.rfsrc}
\alias{gg_variable}
\alias{gg_variable.rfsrc}
\title{Marginal variable depedance data object.}
\usage{
gg_variable.rfsrc(object, time, time.labels, oob = TRUE, ...)
}
\arguments{
\item{object}{a \code{\link[randomForestSRC]{rfsrc}} object}

\item{time}{point (or vector of points) of interest (for survival forests only)}

\item{time.labels}{If more than one time is specified, a vector of time.labels 
for differentiating the time points (for survival forests only)}

\item{oob}{indicate if predicted results should include oob or full data set.}

\item{...}{extra arguments}
}
\value{
\code{gg_variable} object
}
\description{
\code{\link[randomForestSRC]{plot.variable}} generates a \code{data.frame}
 containing the marginal variable dependance or the partial variable dependence. 
 The \code{gg_variable} function creates a \code{data.frame} of containing the 
 full set of covariate data (predictor variables) and the predicted response for 
 each observation. Marginal dependence figures are created using the 
 \code{\link{plot.gg_variable}} function.
}
\details{
The marginal variable dependence is determined by comparing relation
between the predicted response from the randomforest and a covariate of interest.

The \code{gg_variable} function operates on a \code{\link[randomForestSRC]{rfsrc}} object, 
or the output from the \code{\link[randomForestSRC]{plot.variable}} function.
}
\examples{
## ------------------------------------------------------------
## classification
## ------------------------------------------------------------
## -------- iris data
## iris
#rfsrc_iris <- rfsrc(Species ~., data = iris)
data(rfsrc_iris, package="ggRandomForests")

gg_dta <- gg_variable(rfsrc_iris)
plot(gg_dta, xvar="Sepal.Width")
plot(gg_dta, xvar="Sepal.Length")

plot(gg_dta, xvar=rfsrc_iris$xvar.names, 
     panel=TRUE) # , se=FALSE)

## ------------------------------------------------------------
## regression
## ------------------------------------------------------------
\dontrun{
## -------- air quality data
#rfsrc_airq <- rfsrc(Ozone ~ ., data = airquality)
data(rfsrc_airq, package="ggRandomForests")
gg_dta <- gg_variable(rfsrc_airq)

# an ordinal variable 
gg_dta[,"Month"] <- factor(gg_dta[,"Month"])

plot(gg_dta, xvar="Wind")
plot(gg_dta, xvar="Temp")
plot(gg_dta, xvar="Solar.R")


plot(gg_dta, xvar=c("Solar.R", "Wind", "Temp", "Day"), panel=TRUE)

plot(gg_dta, xvar="Month", notch=TRUE)
}
\dontrun{
## -------- motor trend cars data
#rfsrc_mtcars <- rfsrc(mpg ~ ., data = mtcars)
data(rfsrc_mtcars, package="ggRandomForests")
gg_dta <- gg_variable(rfsrc_mtcars)

# mtcars$cyl is an ordinal variable 
gg_dta$cyl <- factor(gg_dta$cyl)
gg_dta$am <- factor(gg_dta$am)
gg_dta$vs <- factor(gg_dta$vs)
gg_dta$gear <- factor(gg_dta$gear)
gg_dta$carb <- factor(gg_dta$carb)

plot(gg_dta, xvar="cyl")

# Others are continuous
plot(gg_dta, xvar="disp")
plot(gg_dta, xvar="hp")
plot(gg_dta, xvar="wt")


# panels
plot(gg_dta,xvar=c("disp","hp", "drat", "wt", "qsec"),  panel=TRUE)
plot(gg_dta, xvar=c("cyl", "vs", "am", "gear", "carb"), panel=TRUE, notch=TRUE)
}
## -------- Boston data

## ------------------------------------------------------------
## survival examples
## ------------------------------------------------------------
\dontrun{
## -------- veteran data
## survival
# data(veteran, package = "randomForestSRC")
# rfsrc_veteran <- rfsrc(Surv(time,status)~., veteran, nsplit = 10, ntree = 100)
data(rfsrc_veteran, package="ggRandomForests")

# get the 1 year survival time.
gg_dta <- gg_variable(rfsrc_veteran, time=90)

# Generate variable dependance plots for age and diagtime
plot(gg_dta, xvar = "age")
plot(gg_dta, xvar = "diagtime", )

# Generate coplots
plot(gg_dta, xvar = c("age", "diagtime"), panel=TRUE, se=FALSE)

# If we want to compare survival at different time points, say 30, 90 day 
# and 1 year
gg_dta <- gg_variable(rfsrc_veteran, time=c(30, 90, 365))

# Generate variable dependance plots for age and diagtime
plot(gg_dta, xvar = "age")
}
## -------- pbc data
}
\seealso{
\code{\link{plot.gg_variable}} \code{\link[randomForestSRC]{plot.variable}}
}

