% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gg_vimp.R
\name{gg_vimp.rfsrc}
\alias{gg_vimp}
\alias{gg_vimp.rfsrc}
\title{Variable Importance (VIMP) data object}
\usage{
gg_vimp.rfsrc(object, n_var, ...)
}
\arguments{
\item{object}{A \code{\link[randomForestSRC]{rfsrc}} object or output from 
\code{\link[randomForestSRC]{vimp}}}

\item{n_var}{select a number pf the highest VIMP variables to plot}

\item{...}{arguments passed to the \code{\link[randomForestSRC]{vimp.rfsrc}} function if the 
\code{\link[randomForestSRC]{rfsrc}} object does not contain importance information.}
}
\value{
\code{gg_vimp} object. A \code{data.frame} of VIMP measures, in rank order.
}
\description{
\code{gg_vimp} Extracts the variable importance (VIMP) information from a
a \code{\link[randomForestSRC]{rfsrc}} object.
}
\examples{
## ------------------------------------------------------------
## classification example
## ------------------------------------------------------------
## -------- iris data
# rfsrc_iris <- rfsrc(Species ~ ., data = iris)
data(rfsrc_iris, package="ggRandomForests")
gg_dta <- gg_vimp(rfsrc_iris)
plot(gg_dta)
 
## ------------------------------------------------------------
## regression example
## ------------------------------------------------------------
\dontrun{
## -------- air quality data 
# rfsrc_airq <- rfsrc(Ozone ~ ., airquality)
data(rfsrc_airq, package="ggRandomForests")
gg_dta <- gg_vimp(rfsrc_airq)
plot(gg_dta)
}

## -------- Boston data
data(rfsrc_Boston, package="ggRandomForests")
gg_dta <- gg_vimp(rfsrc_Boston)
plot(gg_dta)

\dontrun{
## -------- mtcars data
data(rfsrc_mtcars, package="ggRandomForests")
gg_dta <- gg_vimp(rfsrc_mtcars)
plot(gg_dta)
}
## ------------------------------------------------------------
## survival example
## ------------------------------------------------------------
\dontrun{
## -------- veteran data
data(rfsrc_veteran, package="ggRandomForests")
gg_dta <- gg_vimp(rfsrc_veteran)
plot(gg_dta)
}

## -------- pbc data
data(rfsrc_pbc, package="ggRandomForests")
gg_dta <- gg_vimp(rfsrc_pbc)
plot(gg_dta)

# Restrict to only the top 10.
gg_dta <- gg_vimp(rfsrc_pbc, n_var=10)
plot(gg_dta)
}
\references{
Ishwaran H. (2007). Variable importance in binary regression trees and forests, 
\emph{Electronic J. Statist.}, 1:519-537.
}
\seealso{
\code{\link{plot.gg_vimp}} \code{\link[randomForestSRC]{rfsrc}} \code{\link[randomForestSRC]{vimp}}
}

